==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/el.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Διαχειριστείτε Παράμετροι Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "διαχειριστείτε Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Πλάτος εικόνας πλήρους μεγέθους");
define('MANAGE_GALLERY_FULL_HEIGHT', "Ύψος εικόνας πλήρους μεγέθους");
define('MANAGE_GALLERY_THUMB_WIDTH', "Μικρογραφία Πλάτος εικόνας");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Μικρογραφία Ύψος Εικόνας");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Διατηρήστε Αναλογία Thumb");
define('MANAGE_GALLERY_SHOW_TITLES', "Εμφάνιση Τίτλοι");
define('MANAGE_GALLERY_DISABLE_SORT', "Απενεργοποίηση Ταξινόμηση");
define('MANAGE_GALLERY_DELETE_IMAGE', "Διαγραφή εικόνας");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Αποθήκευση Sort Order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Κάντε κλικ στο κουμπί «Ενημέρωση» για να δημοσιεύσει <br /> ανεβάσει τις εικόνες σας.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Όλες οι εικόνες έχουν αλλάξει το μέγεθός τους και οι ρυθμίσεις έχουν αποθηκευτεί.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Παρουσιάστηκε σφάλμα αλλαγή μεγέθους των εικόνων ή την αποθήκευση των ρυθμίσεων.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Η εικόνα σας (ες) έχει φορτωθεί.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Υπήρξε ένα σφάλμα κατά τη μεταφόρτωση της εικόνας σας (ες).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Το αρχείο που προσπαθείτε να φορτώσετε δεν είναι μια εικόνα.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Το αρχείο που προσπαθείτε να φορτώσετε είναι πολύ μεγάλο.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Ο τίτλος έχει αποθηκευτεί.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Είστε σίγουροι ότι θέλετε να διαγράψετε την εικόνα");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', ";");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Η εικόνα έχει διαγραφεί.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Υπήρξε ένα σφάλμα κατά τη διαγραφή της εικόνας.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Αποθήκευση παραμέτρων και αλλαγή μεγέθους των εικόνων, παρακαλώ περιμένετε ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Φόρτωμα, παρακαλώ περιμένετε ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Η σειρά ταξινόμησης δεν έχει σωθεί. Θέλετε να αποθηκεύσετε τη σειρά ταξινόμησης;");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Η σειρά ταξινόμησης εικόνα έχει αποθηκευτεί.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Υπήρξε κατά την αποθήκευση το είδος της εικόνας σφάλμα.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/el.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Διαχειριστείτε Παράμετροι Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "διαχειριστείτε Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Πλάτος εικόνας πλήρους μεγέθους");
define('MANAGE_GALLERY_FULL_HEIGHT', "Ύψος εικόνας πλήρους μεγέθους");
define('MANAGE_GALLERY_THUMB_WIDTH', "Μικρογραφία Πλάτος εικόνας");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Μικρογραφία Ύψος Εικόνας");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Διατηρήστε Αναλογία Thumb");
define('MANAGE_GALLERY_SHOW_TITLES', "Εμφάνιση Τίτλοι");
define('MANAGE_GALLERY_DISABLE_SORT', "Απενεργοποίηση Ταξινόμηση");
define('MANAGE_GALLERY_DELETE_IMAGE', "Διαγραφή εικόνας");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Αποθήκευση Sort Order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Κάντε κλικ στο κουμπί «Ενημέρωση» για να δημοσιεύσει <br /> ανεβάσει τις εικόνες σας.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Όλες οι εικόνες έχουν αλλάξει το μέγεθός τους και οι ρυθμίσεις έχουν αποθηκευτεί.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Παρουσιάστηκε σφάλμα αλλαγή μεγέθους των εικόνων ή την αποθήκευση των ρυθμίσεων.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Η εικόνα σας (ες) έχει φορτωθεί.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Υπήρξε ένα σφάλμα κατά τη μεταφόρτωση της εικόνας σας (ες).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Το αρχείο που προσπαθείτε να φορτώσετε δεν είναι μια εικόνα.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Το αρχείο που προσπαθείτε να φορτώσετε είναι πολύ μεγάλο.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Ο τίτλος έχει αποθηκευτεί.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Είστε σίγουροι ότι θέλετε να διαγράψετε την εικόνα");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', ";");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Η εικόνα έχει διαγραφεί.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Υπήρξε ένα σφάλμα κατά τη διαγραφή της εικόνας.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Αποθήκευση παραμέτρων και αλλαγή μεγέθους των εικόνων, παρακαλώ περιμένετε ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Φόρτωμα, παρακαλώ περιμένετε ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Η σειρά ταξινόμησης δεν έχει σωθεί. Θέλετε να αποθηκεύσετε τη σειρά ταξινόμησης;");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Η σειρά ταξινόμησης εικόνα έχει αποθηκευτεί.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Υπήρξε κατά την αποθήκευση το είδος της εικόνας σφάλμα.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Το αρχείο που προσπαθείτε να μεταφορτώσετε είναι μεγαλύτερο από τις ρυθμίσεις PHP &#39;upload_max_filesize&#39; ή &#39;post_max_size&#39;. Επικοινωνήστε με το διαχειριστή του συστήματος για να αυξήσετε αυτά τα όρια.");
?>
